process.env.NODE_TLS_REJECT_UNAUTHORIZED = '0'
process.env.SUPPRESS_NO_CONFIG_WARNING = true

const httpMocks = require('node-mocks-http')
const fixtures = require('./../fixtures/fixtures')
const Model = require('./../helpers/Model')

jest.mock('pubsweet-component-mail-service', () => ({
  setupRevokeInvitationEmail: jest.fn(),
}))
const { standardCollection } = fixtures.collections
const { editorInChief, handlingEditor, author } = fixtures.users
const { heTeam } = fixtures.teams
const deletePath = '../../routes/collectionsInvitations/delete'
const models = Model.build()

describe('Delete Collections Invitations route handler', () => {
  it('should return an error when the collection does not exist', async () => {
    const req = httpMocks.createRequest()
    req.params.collectionId = 'invalid-id'
    req.user = editorInChief.id
    const res = httpMocks.createResponse()
    await require(deletePath)(models)(req, res)
    expect(res.statusCode).toBe(404)
    const data = JSON.parse(res._getData())
    expect(data.error).toEqual('collection not found')
  })
  it('should return an error when the invitation does not exist', async () => {
    const req = httpMocks.createRequest()
    req.params.collectionId = standardCollection.id
    req.params.invitationId = 'invalid-id'
    req.user = editorInChief.id
    const res = httpMocks.createResponse()
    await require(deletePath)(models)(req, res)
    expect(res.statusCode).toBe(404)
    const data = JSON.parse(res._getData())
    expect(data.error).toEqual('Invitation invalid-id not found')
  })
  it('should return an error when the request user is not editorInChief or admin', async () => {
    const req = httpMocks.createRequest()
    req.params.collectionId = standardCollection.id
    req.params.invitationId = standardCollection.invitations[0].id
    req.user = author.id
    const res = httpMocks.createResponse()
    await require(deletePath)(models)(req, res)
    expect(res.statusCode).toBe(403)
    const data = JSON.parse(res._getData())
    expect(data.error).toEqual(
      'The request user must be Editor in Chief or Admin',
    )
  })
  it('should return success when the collection and invitation exist', async () => {
    const req = httpMocks.createRequest()
    req.params.collectionId = standardCollection.id
    req.params.invitationId = standardCollection.invitations[0].id
    req.user = editorInChief.id
    const res = httpMocks.createResponse()
    const initialSize = standardCollection.invitations.length
    await require(deletePath)(models)(req, res)
    expect(res.statusCode).toBe(200)
    expect(heTeam.members).not.toContain(handlingEditor.id)
    expect(standardCollection.invitations).toHaveLength(initialSize - 1)
    expect(handlingEditor.teams).not.toContain(heTeam.id)
  })
})
